roboscheduler
==============================

FPS robot scheduler software

|Build Status| |Coverage Status|

------------

This README describes the roboscheduler Python package. It should include things like a general description, installation instructions, and requirements. It should also include information badges for other services or packages used, e.g., Travis-CI and Coveralls, ReadtheDocs, Astropy, etc.

.. |Build Status| image:: https://travis-ci.org/blanton144/roboscheduler.svg?branch=master
   :target: https://travis-ci.org/blanton144/roboscheduler

.. |Coverage Status| image:: https://coveralls.io/repos/github/blanton144/roboscheduler/badge.svg?branch=master
   :target: https://coveralls.io/github/blanton144/roboscheduler?branch=master
